@@ -1,6 +1,5 @@
-/* $Id$ */
 /*
- * Copyright (C) 2008 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,16 +21,20 @@
 
 G_BEGIN_DECLS
 
+#define LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
+
+#include <libxfce4panel/libxfce4panel-config.h>
+#include <libxfce4panel/libxfce4panel-enums.h>
 #include <libxfce4panel/libxfce4panel-enum-types.h>
+#include <libxfce4panel/xfce-panel-macros.h>
+#include <libxfce4panel/xfce-panel-macros-46.h>
 #include <libxfce4panel/xfce-arrow-button.h>
 #include <libxfce4panel/xfce-hvbox.h>
 #include <libxfce4panel/xfce-panel-convenience.h>
-#include <libxfce4panel/xfce-panel-enums.h>
-#include <libxfce4panel/xfce-panel-external-plugin.h>
-#include <libxfce4panel/xfce-panel-internal-plugin.h>
-#include <libxfce4panel/xfce-panel-macros.h>
-#include <libxfce4panel/xfce-panel-plugin-iface.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/xfce-panel-image.h>
+
+#undef LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
 
 G_END_DECLS
 
